ewa.lighttpd_hack_middleware

Package ewa :: Module lighttpd_hack_middleware |
[hide private]
[frames] | no frames]

# Source Code for Module ewa.lighttpd_hack_middleware

     1 -class LighttpdHackMiddleware(object):
     2 -    def __init__(self, app, script_name=''):
     3          self.app = app
     4          self.script_name = script_name
     5
     6 -    def __call__(self, environ, start_response):
     7          # overwrite SCRIPT_NAME
     8          environ['SCRIPT_NAME'] = self.script_name
     9          return self.app(environ, start_response)
    10